@@ -1,11 +1,16 @@
-from aquests.lib.attrdict import AttrDict
+from ..lib.attrdict import AttrDict
+from ..lib.cbutil import tuple_cb
 
 class Request:
-	def __init__ (self, dbtype, server, dbname, method, params, callback = None, meta = {}):
+	reauth_count = 0
+	retry_count = 0
+		
+	def __init__ (self, dbtype, server, dbname, auth, method, params, callback = None, meta = {}):
 		self.server = server
 		self.dbname = dbname
+		self.auth = auth
 		self.method = method
-		self.params = params
+		self.params = params		
 		self.meta = meta
 		self.dbtype = dbtype
 		self.callback = callback
@@ -30,7 +35,10 @@ class Request:
 		if self.request.expt_class:
 			return "%s %s" % (self.expt_class, self.expt_str)		
 		return ""
-		
+	
+	def __nonzero__ (self):
+		return self.data and True or False
+			
 	@property
 	def status_code (self):		
 		return self.code
@@ -38,15 +46,18 @@ class Request:
 	@property
 	def reason (self):
 		return self.msg
-			
+	
+	def handle_callback (self):
+		tuple_cb (self, self.callback)
+					
 	def handle_result (self, description, expt_class, expt_str, data):
-		self.expt_class, self.expt_str = expt_class, expt_str
+		self.expt_class, self.expt_str = expt_class, expt_str		
 		if expt_class:
 			self.code, self.msg = 500, "Error"
 
 		self.description = description
 		self.__content = data
-		self.callback (self)
+		self.handle_callback ()
 	
 	@property
 	def content (self):
