@@ -6,7 +6,7 @@ def deprecated (f):
     def wrapper (was, *args, **kwargs):
         warnings.simplefilter ('default')
         warnings.warn (
-           "f.__name__ will be deprecated",
+           "{} will be deprecated".format (f.__name__),
             DeprecationWarning
         )
         return f (was, *args, **kwargs)
