@@ -26,6 +26,8 @@ _select_errors = 0
 _poll_count = 0
 _polling = 0
 _logger = None
+
+EXHAUST_DNS = True
 	
 class Maintern:
 	def __init__ (self):
@@ -187,6 +189,10 @@ def poll_fun_wrap (timeout, map = None):
 
 	if map is None:
 		map = asyncore.socket_map	
+	
+	if EXHAUST_DNS:
+		asyndns.pop_all ()	
+	
 	try:		
 		poll_fun (timeout, map)
 	except (TypeError, OSError) as why:
@@ -212,25 +218,14 @@ def poll_fun_wrap (timeout, map = None):
 	except:
 		_logger and _logger.trace ()
 		raise
-
-def poll_dns (exhaust = False):
-	map = asyndns.socket_map
-	if exhaust:
-		while asyndns.pool:
-			asyncore.loop (0.5, map = map, count = 1)						
-			asyndns.pool.maintern (time.time ())
-			
-	else:	
-		if asyndns.pool:
-			# asyndns.pool.maintern () is scheduled by skitai
-			asyncore.loop (0.1, map = map, count = 2)
 		
 def lifetime_loop (timeout = 30.0, count = 0):
 	global _last_maintern
 	global _maintern_interval
 
-	map = asyncore.socket_map
 	loop = 0
+	map = asyncore.socket_map
+	
 	while map and _shutdown_phase == 0:		
 		poll_fun_wrap (timeout, map)
 		now = time.time()
